# Getting started

## Installation

Instructions for installing `kernpy` are provided below.

### Install the last version of `kernpy` using `pip`

```bash
pip3 install kernpy --upgrade
```


### Install the last version from the repository

```bash
pip install git+https://github.com/OMR-PRAIG-UA-ES/kernpy.git 
```

### Install a specific version from the repository

```bash
pip install git+https://github.com/OMR-PRAIG-UA-ES/kernpy.git@<commit-tag>
```

## Next steps
- [Tutorial](get-started/tutorial.md)
    Learn how to use `kernpy` in a few minutes.




